@@ -69,7 +69,7 @@ class PMMLPipeline(Pipeline):
 			self.target_fields = target_fields
 		return super(PMMLPipeline, self)._fit(X = X, y = y, **fit_params)
 
-	def predict_proba(self, X, **predict_proba_params):
+	def _transform(self, X):
 		Xt = X
 		if hasattr(self, "_iter"):
 			for _, name, transform in self._iter(with_final = False):
@@ -78,8 +78,19 @@ class PMMLPipeline(Pipeline):
 			for name, transform in self.steps[:-1]:
 				if transform is not None:
 					Xt = transform.transform(Xt)
+		return Xt
+
+	def predict_proba(self, X, **predict_proba_params):
+		Xt = self._transform(X)
 		return self.steps[-1][-1].predict_proba(Xt, **predict_proba_params)
 
+	def apply(self, X):
+		Xt = self._transform(X)
+		yt = self.steps[-1][-1].apply(Xt)
+		if len(yt.shape) == 1:
+			yt = yt.reshape(-1, 1)
+		return yt
+
 	def predict_transform(self, X, **predict_params):
 		y_pred = self.predict(X, **predict_params)
 		if self.predict_transformer is not None:
@@ -96,6 +107,13 @@ class PMMLPipeline(Pipeline):
 			return numpy.hstack((y_proba, y_probat))
 		return y_proba
 
+	def apply_transform(self, X):
+		y_apply = self.apply(X)
+		if self.apply_transformer is not None:
+			y_applyt = self.apply_transformer.transform(y_apply)
+			return numpy.hstack((y_apply, y_applyt))
+		return y_apply
+
 	def configure(self, **pmml_options):
 		if len(pmml_options) > 0:
 			estimator = self._final_estimator
@@ -109,7 +127,7 @@ class PMMLPipeline(Pipeline):
 		if self.active_fields is None or active_fields is None:
 			raise ValueError("Cannot perform model validation with anonymous data")
 		if self.active_fields.tolist() != active_fields.tolist():
-			raise ValueError("The columns between training data {} and verification data {} do not match".format(self.active_fields, active_fields))
+			raise ValueError("The columns between training data {0} and verification data {1} do not match".format(self.active_fields, active_fields))
 		active_values = _get_values(X)
 		y = self.predict(X, **predict_params)
 		target_values = _get_values(y)
